Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(862)

Unified Diff: ui/compositor/layer_animator.h

Issue 1904653002: CC Animation: Merge LayerAnimationController into ElementAnimations. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Minor optimization: Don't init value observations if same host. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/trees/tree_synchronizer_unittest.cc ('k') | ui/compositor/layer_animator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/compositor/layer_animator.h
diff --git a/ui/compositor/layer_animator.h b/ui/compositor/layer_animator.h
index 9bd9f058e3bac88dadd52617def36f063d3805f3..e07de31f9206f4863a7165f10d4a2ad3be7a7dda 100644
--- a/ui/compositor/layer_animator.h
+++ b/ui/compositor/layer_animator.h
@@ -26,8 +26,8 @@ namespace cc {
class Animation;
class AnimationPlayer;
class AnimationTimeline;
+class ElementAnimations;
class Layer;
-class LayerAnimationController;
}
namespace gfx {
@@ -408,10 +408,10 @@ class COMPOSITOR_EXPORT LayerAnimator
// aborted.
base::ObserverList<LayerAnimationObserver> observers_;
// We store a state of LayerAnimationController here to save it in
// ResetCompositor/SetCompositor scope.
// TODO(loyso): Remove it. crbug.com/592873.
- scoped_refptr<cc::LayerAnimationController> animation_controller_state_;
+ scoped_refptr<cc::ElementAnimations> element_animations_state_;
DISALLOW_COPY_AND_ASSIGN(LayerAnimator);
};
« no previous file with comments | « cc/trees/tree_synchronizer_unittest.cc ('k') | ui/compositor/layer_animator.cc » ('j') | no next file with comments »
@@ -408,10 +408,10 @@ class COMPOSITOR_EXPORT LayerAnimator
// aborted.
base::ObserverList<LayerAnimationObserver> observers_;
- // We store a state of LayerAnimationController here to save it in
+ // We store a state of ElementAnimations here to save it in
// ResetCompositor/SetCompositor scope.
// TODO(loyso): Remove it. crbug.com/592873.

Powered by Google App Engine
This is Rietveld 408576698